//
// Handles the display of levels
//
//           NGCollector, Sebastian Mihai, 2012
//

#include "cframework\ngpc.h"
#include "cframework\library.h"
#include "levels.h"
#include "globaldefs.h"
#include "messagearea.h"
#include "events.h"
#include "collection.h"

#define BG2_PALETTE_SEPARATOR 0
#define BG2_PALETTE_ROAD 1

#define BG2_PALETTE_CASINO 2
#define BG2_PALETTE_CASINO_2 3
#define BG2_PALETTE_CASINO_3 4
#define BG2_PALETTE_CASINO_DECORATION 5

#define BG2_PALETTE_BRICK_WALL 2

#define BG2_PALETTE_CONVENIENCE 3
#define BG2_PALETTE_CONVENIENCE_GLASS 4

#define BG2_PALETTE_MARKET_WALL 2

#define BG2_PALETTE_BURLY_WALL 2
#define BG2_PALETTE_BURLY_BURGER 3

void private_RenderSeparator() {
	u8 i,j;
	// palette initialization
	SetPalette(SCR_2_PLANE, BG2_PALETTE_SEPARATOR, 0, RGB(13,15,15), RGB(15,0,0), RGB(15,11,11));
	// separator
	for(i=0; i<20; i++)
		PutTile(SCR_2_PLANE,BG2_PALETTE_SEPARATOR,i,10, FIRST_BG_TILE);
}

void private_RenderRoad() {
	u8 i,j;
	// palette initialization
	SetPalette(SCR_2_PLANE, BG2_PALETTE_ROAD, 0, RGB(0,0,0), RGB(13,13,13), RGB(15,15,15));
	
	// road
	for(i=0; i<20; i++)
		for(j=5; j<10; j++)
			PutTile(SCR_2_PLANE,BG2_PALETTE_ROAD,i,j, FIRST_BG_TILE+4);
	
	// road markings
	for(i=2; i<20; i+=4)
		PutTile(SCR_2_PLANE,BG2_PALETTE_ROAD,i,7, FIRST_BG_TILE+1);
	
	// cracks in the road
	PutTile(SCR_2_PLANE,BG2_PALETTE_ROAD,1,8, FIRST_BG_TILE+2);
	PutTile(SCR_2_PLANE,BG2_PALETTE_ROAD,15,8, FIRST_BG_TILE+3);
	PutTile(SCR_2_PLANE,BG2_PALETTE_ROAD,10,6, FIRST_BG_TILE+3);
	PutTile(SCR_2_PLANE,BG2_PALETTE_ROAD,18,5, FIRST_BG_TILE+2);
	
	// sidewalk
	for(i=0; i<20; i++) {
		PutTile(SCR_2_PLANE,BG2_PALETTE_ROAD,i,4, FIRST_BG_TILE+5);
		PutTile(SCR_2_PLANE,BG2_PALETTE_ROAD,i,3, FIRST_BG_TILE+6);
	}
}

void private_LoadFellowClctr() {
	u8 i,j;
	
	private_RenderSeparator();
	private_RenderRoad();
	
	SetPalette(SCR_2_PLANE, BG2_PALETTE_BRICK_WALL, 0, RGB(5,5,5), RGB(14,9,9), RGB(12,9,9));
	
	for(i=0; i<20; i++)
		for(j=0; j<3; j++)
			PutTile(SCR_2_PLANE,BG2_PALETTE_BRICK_WALL,i,j, FIRST_BG_TILE+14);
			
	PrintString(SCR_1_PLANE, 0, 18, 0, "SM");
	
	ClearMessageArea();
	AddMessage( (char*)"You see" );
	AddMessage( (char*)"a fellow collector" );
}

void private_LoadCasino() {
	u8 i,j;
	u8 pal;

	private_RenderSeparator();
	private_RenderRoad();
	
	// palette initialization
	SetPalette(SCR_2_PLANE, BG2_PALETTE_CASINO, 0, RGB(3,3,3), RGB(7,7,10), RGB(15,15,15));
	SetPalette(SCR_2_PLANE, BG2_PALETTE_CASINO_2, 0, RGB(3,8,8), RGB(7,12,12), RGB(15,15,15));
	SetPalette(SCR_2_PLANE, BG2_PALETTE_CASINO_3, 0, RGB(15,0,0), RGB(7,12,12), RGB(15,15,15));
	SetPalette(SCR_2_PLANE, BG2_PALETTE_CASINO_DECORATION, 0, RGB(15,0,0), RGB(7,12,12), RGB(12,12,5));
	
	for(i=0; i<20; i++) {
		if(i==7)i=12;
		pal = BG2_PALETTE_CASINO;
		if( i%2 ) pal = BG2_PALETTE_CASINO_2;
		PutTile(SCR_2_PLANE,pal,i,0, FIRST_BG_TILE+7);
		PutTile(SCR_2_PLANE,pal,i,1, FIRST_BG_TILE+9);
		PutTile(SCR_2_PLANE,pal,i,2, FIRST_BG_TILE+8);
	}
	// the sign
	PutTile(SCR_2_PLANE,BG2_PALETTE_CASINO_3,8,0, FIRST_BG_TILE+10);
	PutTile(SCR_2_PLANE,BG2_PALETTE_CASINO_3,9,0, FIRST_BG_TILE+11);
	PutTile(SCR_2_PLANE,BG2_PALETTE_CASINO_3,10,0, FIRST_BG_TILE+12);
	
	// to the left and right of sign
	PutTile(SCR_2_PLANE,BG2_PALETTE_CASINO,7,0, FIRST_BG_TILE+13);
	PutTile(SCR_2_PLANE,BG2_PALETTE_CASINO,11,0, FIRST_BG_TILE+13);
	
	// sides
	PutTile(SCR_2_PLANE,BG2_PALETTE_CASINO,7,1, FIRST_BG_TILE+22);
	PutTile(SCR_2_PLANE,BG2_PALETTE_CASINO,7,2, FIRST_BG_TILE+22);
	PutTile(SCR_2_PLANE,BG2_PALETTE_CASINO,11,1, FIRST_BG_TILE+23);
	PutTile(SCR_2_PLANE,BG2_PALETTE_CASINO,11,2, FIRST_BG_TILE+23);
	
	// door
	PutTile(SCR_2_PLANE,BG2_PALETTE_CASINO,9,1, FIRST_BG_TILE+20);
	PutTile(SCR_2_PLANE,BG2_PALETTE_CASINO,9,2, FIRST_BG_TILE+21);
	
	// decorations
	PutTile(SCR_2_PLANE,BG2_PALETTE_CASINO_DECORATION,8,1, FIRST_BG_TILE+25);
	PutTile(SCR_2_PLANE,BG2_PALETTE_CASINO_DECORATION,8,2, FIRST_BG_TILE+25);
	PutTile(SCR_2_PLANE,BG2_PALETTE_CASINO_DECORATION,10,1, FIRST_BG_TILE+25);
	PutTile(SCR_2_PLANE,BG2_PALETTE_CASINO_DECORATION,10,2, FIRST_BG_TILE+25);

	ClearMessageArea();
	AddMessage( (char*)"You see" );
	AddMessage( (char*)"a fancy casino" );
}

void private_LoadFleaMarket() {
	u8 i,j;
	u8 pal;

	private_RenderSeparator();
	private_RenderRoad();
	
	// palette initialization
	SetPalette(SCR_2_PLANE, BG2_PALETTE_CASINO, 0, RGB(3,3,3), RGB(7,7,10), RGB(15,15,15));
	SetPalette(SCR_2_PLANE, BG2_PALETTE_MARKET_WALL, 0, RGB(4,4,4), RGB(8,8,8), RGB(12,12,12));
	
	for( i=0; i<16; i+=5 ) {
		// wall
		for(j=0;j<3;j++) {
			PutTile(SCR_2_PLANE,BG2_PALETTE_BRICK_WALL,i,j, FIRST_BG_TILE+14);
			PutTile(SCR_2_PLANE,BG2_PALETTE_BRICK_WALL,i+4,j, FIRST_BG_TILE+14);
		}
		
		PutTile(SCR_2_PLANE,BG2_PALETTE_CASINO,i+1,1, FIRST_BG_TILE+22);
		PutTile(SCR_2_PLANE,BG2_PALETTE_CASINO,i+1,2, FIRST_BG_TILE+22);
		PutTile(SCR_2_PLANE,BG2_PALETTE_CASINO,i+3,1, FIRST_BG_TILE+23);
		PutTile(SCR_2_PLANE,BG2_PALETTE_CASINO,i+3,2, FIRST_BG_TILE+23);
		
		PutTile(SCR_2_PLANE,BG2_PALETTE_CASINO,i+2,1, FIRST_BG_TILE+20);
		PutTile(SCR_2_PLANE,BG2_PALETTE_CASINO,i+2,2, FIRST_BG_TILE+21);
	};
	
	for( i=0; i<20; i++ ) {
		// wall
		PutTile(SCR_2_PLANE,BG2_PALETTE_BRICK_WALL,i,0, FIRST_BG_TILE+14);
	}

	ClearMessageArea();
	AddMessage( (char*)"You see" );
	AddMessage( (char*)"a shady flea market" );
}

void private_LoadConvenience() {
	u8 i,j;
	
	private_RenderSeparator();
	private_RenderRoad();
	
	SetPalette(SCR_2_PLANE, BG2_PALETTE_BRICK_WALL, 0, RGB(0,0,0), RGB(8,3,3), RGB(6,3,3));
	SetPalette(SCR_2_PLANE, BG2_PALETTE_CONVENIENCE, 0, RGB(0,0,15), RGB(0,7,0), RGB(15,3,3));
	SetPalette(SCR_2_PLANE, BG2_PALETTE_CONVENIENCE_GLASS, 0, RGB(0,0,15), RGB(12,12,15), RGB(15,3,3));
	
	for(i=0; i<20; i++)
		for(j=0; j<3; j++)
			if( i < 8 || i > 12 )
				PutTile(SCR_2_PLANE,BG2_PALETTE_BRICK_WALL,i,j, FIRST_BG_TILE+14);
	
	// sign
	PutTile(SCR_2_PLANE,BG2_PALETTE_CONVENIENCE,8,0, FIRST_BG_TILE+15);
	PutTile(SCR_2_PLANE,BG2_PALETTE_CONVENIENCE,9,0, FIRST_BG_TILE+16);
	PutTile(SCR_2_PLANE,BG2_PALETTE_CONVENIENCE,10,0, FIRST_BG_TILE+17);
	PutTile(SCR_2_PLANE,BG2_PALETTE_CONVENIENCE,11,0, FIRST_BG_TILE+18);
	PutTile(SCR_2_PLANE,BG2_PALETTE_CONVENIENCE,12,0, FIRST_BG_TILE+19);
	
	// sides
	PutTile(SCR_2_PLANE,BG2_PALETTE_CONVENIENCE,8,1, FIRST_BG_TILE+22);
	PutTile(SCR_2_PLANE,BG2_PALETTE_CONVENIENCE,8,2, FIRST_BG_TILE+22);
	PutTile(SCR_2_PLANE,BG2_PALETTE_CONVENIENCE,12,1, FIRST_BG_TILE+23);
	PutTile(SCR_2_PLANE,BG2_PALETTE_CONVENIENCE,12,2, FIRST_BG_TILE+23);
	
	// door
	PutTile(SCR_2_PLANE,BG2_PALETTE_CONVENIENCE,10,1, FIRST_BG_TILE+20);
	PutTile(SCR_2_PLANE,BG2_PALETTE_CONVENIENCE,10,2, FIRST_BG_TILE+21);
	// glass
	PutTile(SCR_2_PLANE,BG2_PALETTE_CONVENIENCE_GLASS,9,1, FIRST_BG_TILE+24);
	PutTile(SCR_2_PLANE,BG2_PALETTE_CONVENIENCE_GLASS,11,1, FIRST_BG_TILE+24);
			
	//for(i=0; i<20; i+=3) PrintString(SCR_1_PLANE, 0, i, 0, "SM");

	ClearMessageArea();
	AddMessage( (char*)"You see" );
	AddMessage( (char*)"a convenience store" );
}

void private_LoadBurlyBurger() {
	u8 i,j;
	u8 pal;

	private_RenderSeparator();
	private_RenderRoad();
	
	// palette initialization
	SetPalette(SCR_2_PLANE, BG2_PALETTE_BURLY_WALL, 0, RGB(8,8,5), RGB(15,15,10), RGB(15,15,7));
	SetPalette(SCR_2_PLANE, BG2_PALETTE_BURLY_BURGER, 0, RGB(15,0,0), RGB(12,8,8), RGB(15,7,7));
	
	for( i=0; i<20; i++ ) {
		// wall
		for(j=0;j<3;j++) {
			PutTile(SCR_2_PLANE,BG2_PALETTE_BURLY_WALL,i,j, FIRST_BG_TILE+14);
			PutTile(SCR_2_PLANE,BG2_PALETTE_BURLY_WALL,i+4,j, FIRST_BG_TILE+14);
		}	
	};
	
	PutTile(SCR_2_PLANE,BG2_PALETTE_BURLY_BURGER,6,1, FIRST_BG_TILE+22);
	PutTile(SCR_2_PLANE,BG2_PALETTE_BURLY_BURGER,6,2, FIRST_BG_TILE+22);
	PutTile(SCR_2_PLANE,BG2_PALETTE_BURLY_BURGER,13,1, FIRST_BG_TILE+23);
	PutTile(SCR_2_PLANE,BG2_PALETTE_BURLY_BURGER,13,2, FIRST_BG_TILE+23);
	
	PutTile(SCR_2_PLANE,BG2_PALETTE_BURLY_BURGER,7,1, FIRST_BG_TILE+20);
	PutTile(SCR_2_PLANE,BG2_PALETTE_BURLY_BURGER,7,2, FIRST_BG_TILE+21);
	
	PutTile(SCR_2_PLANE,BG2_PALETTE_BURLY_BURGER,8,1, FIRST_BG_TILE+23);
	PutTile(SCR_2_PLANE,BG2_PALETTE_BURLY_BURGER,8,2, FIRST_BG_TILE+23);
	
	PutTile(SCR_2_PLANE,BG2_PALETTE_BURLY_BURGER,9,1, FIRST_BG_TILE+22);
	PutTile(SCR_2_PLANE,BG2_PALETTE_BURLY_BURGER,9,2, FIRST_BG_TILE+22);
	
	PutTile(SCR_2_PLANE,BG2_PALETTE_BURLY_BURGER,10,1, FIRST_BG_TILE+20);
	PutTile(SCR_2_PLANE,BG2_PALETTE_BURLY_BURGER,10,2, FIRST_BG_TILE+21);
	
	PutTile(SCR_2_PLANE,BG2_PALETTE_BURLY_BURGER,11,1, FIRST_BG_TILE+23);
	PutTile(SCR_2_PLANE,BG2_PALETTE_BURLY_BURGER,11,2, FIRST_BG_TILE+23);
	
	PutTile(SCR_2_PLANE,BG2_PALETTE_BURLY_BURGER,12,1, FIRST_BG_TILE+22);
	PutTile(SCR_2_PLANE,BG2_PALETTE_BURLY_BURGER,12,2, FIRST_BG_TILE+22);
	
	PutTile(SCR_2_PLANE,BG2_PALETTE_BURLY_BURGER,13,1, FIRST_BG_TILE+20);
	PutTile(SCR_2_PLANE,BG2_PALETTE_BURLY_BURGER,13,2, FIRST_BG_TILE+21);
	
	PutTile(SCR_2_PLANE,BG2_PALETTE_BURLY_BURGER,14,1, FIRST_BG_TILE+23);
	PutTile(SCR_2_PLANE,BG2_PALETTE_BURLY_BURGER,14,2, FIRST_BG_TILE+23);
	
	// the sign
	for(i=6;i<15;i++)
		PutTile(SCR_2_PLANE,BG2_PALETTE_BURLY_BURGER,i,0, FIRST_BG_TILE+20+i);

	ClearMessageArea();
	AddMessage( (char*)"You see" );
	AddMessage( (char*)"Burly Burger" );
}

void LoadLevel( u8 which ) {
	if( which == LEVEL_CASINO ) private_LoadCasino();
	if( which == LEVEL_FELLOW_COLLECTOR) private_LoadFellowClctr();
	if( which == LEVEL_FLEA_MARKET ) private_LoadFleaMarket();
	if( which == LEVEL_CONVENIENCE_STORE ) private_LoadConvenience();
	if( which == LEVEL_BURLY_BURGER ) private_LoadBurlyBurger();
}

