//
// Handles the message area at the bottom of the screen
//
//           NGCollector, Sebastian Mihai, 2012
//

#include "cframework\ngpc.h"
#include "cframework\library.h"

#include "messagearea.h"
#include "globaldefs.h"

#define MESSAGE_AREA_LINES 8

// a miscellaneous message
#define TEXT_MESSAGE 9
// a game name as the message
#define GAME_MESSAGE 8
// a dollar amount as the message
#define AMOUNT_MESSAGE 7

// stores the lines of the message area
char *private_MessageAreaLines[MESSAGE_AREA_LINES];
u16 private_MessageAreaAmounts[MESSAGE_AREA_LINES];
// stores the types of each message line
u8 private_MessageAreaLineTypes[MESSAGE_AREA_LINES];

void private_ShiftMessagesUp() {
	u8 i;
	
	// shift all messages vertically
	for(i=0; i<MESSAGE_AREA_LINES-1; i++) {
		private_MessageAreaLines[i] = private_MessageAreaLines[i+1];
		private_MessageAreaLineTypes[i] = private_MessageAreaLineTypes[i+1];
		private_MessageAreaAmounts[i] = private_MessageAreaAmounts[i+1];
	}
}

void AddMessageGame( char* message ) {

	private_ShiftMessagesUp();

	private_MessageAreaLines[MESSAGE_AREA_LINES-1] = message;
	private_MessageAreaLineTypes[MESSAGE_AREA_LINES-1] = GAME_MESSAGE;

	RenderMessageArea();
	
}

void AddMessage( char* message ) {

	private_ShiftMessagesUp();

	private_MessageAreaLines[MESSAGE_AREA_LINES-1] = message;
	private_MessageAreaLineTypes[MESSAGE_AREA_LINES-1] = TEXT_MESSAGE;

	RenderMessageArea();
	
}

void AddAmountMessage( u16 amount ) {
	
	private_ShiftMessagesUp();
	// we show amount in a different colour than normal text
	private_MessageAreaAmounts[MESSAGE_AREA_LINES-1] = amount;
	private_MessageAreaLineTypes[MESSAGE_AREA_LINES-1] = AMOUNT_MESSAGE;

	RenderMessageArea();
}

void AddMessageBlank() {
	AddMessage( (char*)" " );	
}

u8 CalculateDigits( s32 amount ) {
	u8 digits;
	
	if( amount >= 1000000 ) digits = 7;
	else if( amount >= 100000 ) digits = 6;
	else if( amount >= 10000 ) digits = 5;
	else if( amount >= 1000 ) digits = 4;
	else if( amount >= 100 ) digits = 3;
	else if( amount >= 10 ) digits = 2;
	else digits = 1;
	
	return digits;
}

void RenderMessageArea() {
	u8 i, y, x;
	u16 amount;

	// game name colour
	SetColors(SCR_2_PLANE, GAME_MESSAGE, 0, 0, RGB(0, 0, 0));
	
	// main message area text colour
	SetColors(SCR_2_PLANE, TEXT_MESSAGE, 0, 0, RGB(2, 7, 7));
	
	for(i=0; i<MESSAGE_AREA_LINES; i++) {
		y = TOTAL_TEXT_LINES-MESSAGE_AREA_LINES+i;
		x = 0;
		
		
		if( private_MessageAreaLineTypes[i] == AMOUNT_MESSAGE ) {
			amount = private_MessageAreaAmounts[i];
			
			PrintString(SCR_2_PLANE, TEXT_MESSAGE, 0, y, "                    ");
			PrintString(SCR_2_PLANE, GAME_MESSAGE, 3, y, "$ ");
			PrintDecimal(SCR_2_PLANE, GAME_MESSAGE, 5, y, amount, CalculateDigits(amount) );
			continue;
		}
		
		if( private_MessageAreaLineTypes[i] == GAME_MESSAGE ) {
			// game names are centered in their message area line
			x = 3;
		}
		
		PrintString(SCR_2_PLANE, TEXT_MESSAGE, 0, y, "                    ");
		PrintString(SCR_2_PLANE, private_MessageAreaLineTypes[i], x, y, private_MessageAreaLines[i]);
	}
}

void ClearMessageArea() {
	u8 i;

	for(i=0; i<MESSAGE_AREA_LINES; i++) {
		private_MessageAreaLineTypes[i] = TEXT_MESSAGE;
		AddMessage((char*)" ");
	}
}



