//
//  NGCOLLECTOR
//
//  This NGPC game is meant to simulate the life of a Neo Geo AES collector.
//  
//  Given the exorbitant cost of such an enterprise, you will have to undertake
//  questionable tasks, toil at a day job, gamble, or a combination thereof, in
//  an attempt to build a complete collection of Neo Geo AES (home) cartridges.
//
//  If you have any questions regarding the code, contact me
//  via the method specified at  http://www.sebastianmihai.com
//  (operational in 2012), and I will try my best to help.
//
//                             Sebastian Mihai, 2012
//

// platform includes
#include "cframework\ngpc.h"
#include "carthdr.h"
#include "cframework\library.h"

// standard C includes
#include <stdlib.h>
#include <stdio.h>

// NGCOLLECTOR routines
#include "globaldefs.h"
#include "collection.h"
#include "gameplay.h"
#include "graphics.h"


// Game initialization
void InitializeNGCollector() {
	u16 i;
	
	// no games are owned initially
	for(i=0; i<GAME_COUNT; i++) {
		GameOwn[i] = 0;
	}
	
	// start up our random number sequence
	SeedRandom();
	
	// palettes, colours, oh my!
	SetBackgroundColour(RGB(15, 15, 15));
	
	// initialize message area
	ClearMessageArea();

    SetColors(SCR_1_PLANE, 1, 0, 0, RGB(15, 0, 0));
    SetColors(SCR_1_PLANE, 2, 0, 0, RGB(0, 0, 0));
    SetColors(SCR_1_PLANE, 3, 0, 0, RGB(0, 0, 0));
    SetColors(SCR_1_PLANE, 4, 0, 0, RGB(0, 0, 0));
    SetColors(SCR_1_PLANE, 5, 0, 0, RGB(0, 0, 0));
    SetColors(SCR_1_PLANE, 6, 0, 0, RGB(0, 0, 0));
    SetColors(SCR_1_PLANE, 7, 0, 0, RGB(0, 0, 0));
    SetColors(SCR_1_PLANE, 8, 0, 0, RGB(0, 0, 0));
    SetColors(SCR_1_PLANE, 9, 0, 0, RGB(0, 0, 0));
	
	//
	// Plane 2 is used for text output (using palettes 5-9)
	//         and for the ground (using palettes 0-4)
	// Plane 1 is used for environment (buildings) and static NPCs
	//
	
	// load graphics
	InstallTileSetAt(CurrentTileSet, sizeof(CurrentTileSet)/2, FIRST_SPRITE_TILE);
	
	// load background tiles
	InstallTileSetAt(CommonBackgroundTiles, sizeof(CommonBackgroundTiles)/2, FIRST_BG_TILE);
}



const char author[] = "    NGCOLLECTOR, by Sebastian Mihai, 2012    ";

void DrawCartridge(u8 x, u8 y, u8 palette) {
	PutTile(SCR_1_PLANE,palette,x,y, FIRST_BG_TILE+35);
	PutTile(SCR_1_PLANE,palette,x+1,y, FIRST_BG_TILE+36);
	PutTile(SCR_1_PLANE,palette,x,y+1, FIRST_BG_TILE+37);
	PutTile(SCR_1_PLANE,palette,x+1,y+1, FIRST_BG_TILE+38);
}

void MainMenu() {
	u8 i, j;
	
	SetPalette(SCR_1_PLANE, 0, 0, RGB(0,0,0), RGB(15,0,0), RGB(0,0,15));
	SetPalette(SCR_1_PLANE, 1, 0, RGB(0,0,0), RGB(0,13,15), RGB(0,0,15));
	for(i=0;i<19;i+=2) {
		DrawCartridge( i, 0, (i/2)%2 );
		DrawCartridge( i, 17, (i/2 + 1)%2 );
	}

	SetColors(SCR_2_PLANE, 1, 0, 0, RGB(15, 0, 11));
	SetColors(SCR_2_PLANE, 2, 0, 0, RGB(0, 9, 0));
	
	PrintString(SCR_2_PLANE, 1, 2, 4, "NGCOLLECTOR");
	
	PrintString(SCR_2_PLANE, 0, 10, 11, "a game by ");
	PrintString(SCR_2_PLANE, 0, 4, 12, "Sebastian Mihai");
	PrintString(SCR_2_PLANE, 0, 15, 13, "2012");
	
	PrintString(SCR_2_PLANE, 2, 2, 7, "Live the life of");
	PrintString(SCR_2_PLANE, 2, 2, 8, "a Neo Geo AES");
	PrintString(SCR_2_PLANE, 2, 2, 9, "collector !");
	
	PrintString(SCR_2_PLANE, 0, 3, 15, "[A] to start");
	
	// debounce
	while(SYS_LEVER != 0) { WaitVsync(); }
	i=0; j=2;
	while(1) { 
		WaitVsync(); 
		i++;
		
		if(i % 5 == 0 ) j++;
		if( j > 15 ) j = 15;
		
		SetPalette(SCR_1_PLANE, 0, 0, RGB(0,0,0), RGB(j,0,0), RGB(0,0,j));
		SetPalette(SCR_1_PLANE, 1, 0, RGB(0,0,0), RGB(0,j-2,j), RGB(0,0,j));
		
		// create some chaos
		GetRandom(100);
		
		if( SYS_LEVER & J_A )
			break;
	}
	
	// debounce
	while(SYS_LEVER != 0) { WaitVsync(); }
}

//
// Program entry point
// 
void main(void) {

    InitNGPC();
    SysSetSystemFont();
	
	InitializeNGCollector();

    while(1) {
		// Clear screen
		FillScreen(SCR_1_PLANE, (u16)' ', 0);
		FillScreen(SCR_2_PLANE, (u16)' ', 0);
		//PlayWaveSound();
		MainMenu();
		
		// Clear screen
		FillScreen(SCR_1_PLANE, (u16)' ', 0);
		FillScreen(SCR_2_PLANE, (u16)' ', 0);
		MainGame();
	}
}


// EOF
